@@ -1,4 +1,4 @@
-/* Copyright 2013 Little IO
+/* Copyright 2013-2014 Little IO
  *
  * mopo is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,8 @@
 
 namespace mopo {
 
+  // A signal delay processor with wet/dry, delay time and feedback controls.
+  // Handles fractional delay amounts through interpolation.
   class Delay : public Processor {
     public:
       enum Inputs {
@@ -39,7 +41,16 @@ namespace mopo {
       virtual void process();
 
     protected:
-      mopo_float tick(int i);
+      mopo_float tick(int i) {
+        mopo_float input = inputs_[kAudio]->at(i);
+        mopo_float wet = inputs_[kWet]->at(i);
+        mopo_float period = inputs_[kDelayTime]->at(i) * sample_rate_;
+        mopo_float feedback = inputs_[kFeedback]->at(i);
+
+        mopo_float read = memory_.get(period);
+        memory_.push(input + read * feedback);
+        return INTERPOLATE(input, read, wet);
+      }
 
       Memory memory_;
   };
