@@ -1,4 +1,4 @@
-/* Copyright 2013 Little IO
+/* Copyright 2013-2014 Little IO
  *
  * mopo is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@ namespace mopo {
   void SmoothFilter::process() {
     mopo_float decay = inputs_[kDecay]->at(0);
 
-    for (int i = 0; i < BUFFER_SIZE; ++i) {
+    for (int i = 0; i < buffer_size_; ++i) {
       mopo_float target = inputs_[kTarget]->at(i);
       last_value_ = INTERPOLATE(last_value_, target, decay);
       outputs_[0]->buffer[i] = last_value_;
