@@ -18,6 +18,7 @@
 
 #include "cJSON.h"
 
+#include <cstdio>
 #include <cstdlib>
 #include <dirent.h>
 #include <fstream>
@@ -25,7 +26,6 @@
 #include <ncurses.h>
 #include <sstream>
 #include <string>
-#include <stdio.h>
 #include <sys/stat.h>
 
 #define KEYBOARD "awsedftgyhujkolp;'"
@@ -115,9 +115,9 @@ namespace mopo {
     pthread_mutex_init(&mutex_, 0);
   }
 
-  void Cursynth::start() {
+  void Cursynth::start(unsigned sample_rate, unsigned buffer_size) {
     // Setup all callbacks.
-    setupAudio();
+    setupAudio(sample_rate, buffer_size);
     setupMidi();
     setupGui();
     loadConfiguration();
@@ -287,7 +287,17 @@ namespace mopo {
     return true;
   }
 
-  void Cursynth::setupAudio() {
+  unsigned int Cursynth::chooseSampleRate(const RtAudio::DeviceInfo& device,
+                                          unsigned preferred_sample_rate) {
+    for (int i = 0; i < device.sampleRates.size(); ++i) {
+      if (device.sampleRates[i] == preferred_sample_rate)
+        return preferred_sample_rate;
+    }
+
+    return device.sampleRates[0];
+  }
+
+  void Cursynth::setupAudio(unsigned sample_rate, unsigned buffer_size) {
     // Make sure we have a device to make sound with.
     if (dac_.getDeviceCount() < 1) {
       std::cout << "No audio devices found.\n";
@@ -299,21 +309,24 @@ namespace mopo {
     parameters.deviceId = dac_.getDefaultOutputDevice();
     parameters.nChannels = NUM_CHANNELS;
     parameters.firstChannel = 0;
-    unsigned int sample_rate = 44100;
-    unsigned int buffer_frames = 64;
+    RtAudio::DeviceInfo device_info = dac_.getDeviceInfo(parameters.deviceId);
 
-    synth_.setSampleRate(sample_rate);
+    unsigned actual_sample_rate = chooseSampleRate(device_info, sample_rate);
+    synth_.setSampleRate(actual_sample_rate);
+    buffer_size = CLAMP(buffer_size, 0, mopo::MAX_BUFFER_SIZE);
 
     // Start the audio callbacks.
     try {
-      dac_.openStream(&parameters, NULL, RTAUDIO_FLOAT64, sample_rate,
-                      &buffer_frames, &audioCallback, (void*)this);
+      dac_.openStream(&parameters, NULL, RTAUDIO_FLOAT64, actual_sample_rate,
+                      &buffer_size, &audioCallback, (void*)this);
       dac_.startStream();
     }
     catch (RtError& error) {
       error.printMessage();
       exit(0);
     }
+
+    synth_.setBufferSize(buffer_size);
   }
 
   void Cursynth::setupGui() {
